ScreenOnFlutter class

Constructors

ScreenOnFlutter({ChannelScreenOnFlutter? MethodChannel, required void routeCallback(dynamic)})

Properties

channel ChannelScreenOnFlutter
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
routeCallback → void Function(dynamic)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

endService() Future<StatusBase>
Stops the service.
getPlatformVersion() Future<String?>
moveToBack() Future<StatusBase>
The moveToBack method closes the screen that appears when the device is turned on.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
requestPermission() Future<StatusBase>
Requests the necessary permissions.
startService({required AlarmModel model}) Future<StatusBase>
Starts the service.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited